/* A texture mapping fragment shader. This shader
   looks up a location in the texture pointed to by 
   the sampler2D variable image, using the interpolated 
   values of the varying texture coordinate as indices.
   The texure color is then modulated by the interpolated
   vertex color (gl_Color).

   This is a fairly simplistic method of texture mapping,
   as it does not take into account issues such as per-
   spective corrected mapping, and does not use system
   variables for (u,v) coordinate support.

   User-side (u,v) coordinate variables are used to 
   demonstrate how custom-defined variables may be
   communicated between shaders and C programs.
*/   

uniform sampler2D image;

varying vec2 fragment_texture_coordinate;

void main(void)
{
	gl_FragColor = texture2D(image, fragment_texture_coordinate)*gl_Color;
}

